==> kara-uc-1.1.16.tgz: package/src/kara-uc/components/UCFavorite/All/linkComponent/index.js <==
import React, {Component} from 'react'
import {inject, observer} from "mobx-react"
import css from './index.scss'
import DataUtil from '../../../../util/dateTime'
import Modal from 'react-modal-plugin'
import Forward from 'kara-module-forward'
import 'kara-module-forward/lib/index.css'
import tost,{errorTost} from "kara-module-tost";
import 'kara-module-tost/lib/index.css'

@observer
class LinkComponent extends Component{
  constructor(props) {
    super(props)
    this.state = {
      showmodal: false,
      showForwardModal: false,
      messageId: ''
    }
  }
  cancelFavorite = (id,type) => {
    this.props.httpAgent.post(`/webapi/message/favorite/${id}/no`).then(
      res => {
        if(res && res.resultCode && res.resultCode === '000000') {
          tost({type:'success',msg:'取消收藏成功',time:4}) 
          this.props.cancelImFavorite(id, type, this.props.fromPage)
        }
        else {
          tost({type:'error',msg:'取消收藏失败',time:4}) 
        }
      }
    )
  }
  modalShow = (id) => {
    this.setState({showmodal: true})
    this.setState({messageId: id})
  }
  modalHide = () => {
    this.setState({showmodal: false})
  }
  modalForwardShow = (id) => {
    this.setState({showForwardModal: true})
    this.setState({messageId: id})
  }
  modalForwardHide = () => {
    this.setState({showForwardModal: false})
  }
  render(){
    const {lang} = this.props
    let fileAttr = this.props.fileAttr
    return (<div className={`s-b-secondary ${css.linkContainer}`}>
              <ul className={css.linkItem}>
                <li>
                  <div>
                    <p><img src={fileAttr.richAttachments[0].imageUrl} alt='图片'/></p>
                    <div>
                      <span>{fileAttr.richTitle}</span>
                      <span>{fileAttr.richAttachments[0].description}</span>
                    </div>
                  </div>
                </li>
                <li className='s-hint'>
                  <span>{lang.source}&nbsp;{fileAttr.fromUserName}</span>
                  <span>{DataUtil.DateShow(fileAttr.ts)}</span>
                  <span className={css.hoverShow} onClick={()=>{this.modalForwardShow(fileAttr.messageId)}}><i className='kuc-iconfont kuc-forward'></i>&nbsp;{lang.forward}</span>
                  <span className={css.hoverShow} onClick={()=>{this.cancelFavorite(fileAttr.id,fileAttr.favoriteType)}}><i className='kuc-iconfont kuc-favorite s-primary'></i>&nbsp;取消收藏</span>
                </li>
              </ul>
              <Modal show={this.state.showForwardModal} onMask={this.modalForwardHide}>
                <Forward httpAgent={this.props.httpAgent} modalHidden={this.modalForwardHide} messageId={this.state.messageId} />
              </Modal>
            </div>
            )
  }
}

export default LinkComponent

==> kara-uc-1.1.29.tgz: package/src/kara-uc/components/UCFavorite/All/linkComponent/index.js <==
import React, {Component} from 'react'
import css from './index.scss'
import DataUtil from '../../../../util/dateTime'
import Modal from 'react-modal-plugin'
import tost,{errorTost} from "kara-module-tost";
import 'kara-module-tost/lib/index.css'

class LinkComponent extends Component{
  constructor(props) {
    super(props)
    this.state = {
      showmodal: false,
      showForwardModal: false,
      messageId: '',
       height: 'auto'
    }
    this.container = React.createRef()
  }

  componentDidMount() {
    if (this.state.height === 'auto' && this.container.current) {
        this.setState({ height: this.container.current.offsetHeight})
    }
  }

  cancelFavorite = (id,type) => {
    this.props.httpAgent.post(`/webapi/message/favorite/${id}/no`).then(
      res => {
        if(res && res.resultCode && res.resultCode === '000000') {
          tost({type:'success',msg:'取消收藏成功',time:4}) 
          this.props.cancelImFavorite(id, type, this.props.fromPage)
        }
        else {
          tost({type:'error',msg:'取消收藏失败',time:4}) 
        }
      }
    )
  }
  modalShow = (id) => {
    this.setState({showmodal: true})
    this.setState({messageId: id})
  }
  modalHide = () => {
    this.setState({showmodal: false})
  }
  modalForwardShow = (id) => {
    this.setState({showForwardModal: true})
    this.setState({messageId: id})
  }
  modalForwardHide = () => {
    this.setState({showForwardModal: false})
  }
  render(){
    const {lang, karaui:{Forward}} = this.props
    let fileAttr = this.props.fileAttr
    return (<div ref={this.container} className={`s-b-secondary ${css.linkContainer}`} style={{height: fileAttr.canceled ? 0 : this.state.height}}>
              <ul className={css.linkItem}>
                <li>
                  <div>
                    <p><img src={fileAttr.richAttachments[0].imageUrl} alt='图片'/></p>
                    <div>
                      <span>{fileAttr.richTitle}{fileAttr.canceled}</span>
                      <span>{fileAttr.richAttachments[0].description}</span>
                    </div>
                  </div>
                </li>
                <li className='s-hint'>
                  <span>{lang.source}&nbsp;{fileAttr.fromUserName}</span>
                  <span>{DataUtil.DateShow(fileAttr.ts)}</span>
                  <span className={css.hoverShow} onClick={()=>{this.modalForwardShow(fileAttr.messageId)}}><i className='kuc-iconfont kuc-forward'></i>&nbsp;{lang.forward}</span>
                  <span className={css.hoverShow} onClick={()=>{this.cancelFavorite(fileAttr.id,fileAttr.favoriteType)}}><i className='kuc-iconfont kuc-favorite s-primary'></i>&nbsp;取消收藏</span>
                </li>
              </ul>
              <Modal show={this.state.showForwardModal} onMask={this.modalForwardHide}>
                <Forward httpAgent={this.props.httpAgent} modalHidden={this.modalForwardHide} messageId={this.state.messageId} />
              </Modal>
            </div>
            )
  }
}

export default LinkComponent
